@@ -157,8 +157,8 @@ MainWindow::MainWindow(QWidget *parent)
     if (settings->value("firstLaunch", "") != APP_VER)
     {
         QMessageBox::about(this,
-                           tr("First launch"),
-                           tr("Welcome to a new version of <b>fahrplan</b> this is new:<br><br>- complete rewrite in QT for better portability and a future in meego<br>- adding settings to enable/disable gps autostart<br>- adding settings to enable/disable openstreetmap gps fallback<br>- adding support for mvv-muenchen.de and settings to change the data backend<br>- adding support to enable/disable gps")
+                           tr("Welcome to a new version of fahrplan this is new"),
+                           tr("- fixed a dbus related 2 min after start crash<br>- complete rewrite in QT for better portability and a future in meego<br>- adding settings to enable/disable gps autostart<br>- adding settings to enable/disable openstreetmap gps fallback<br>- adding support for mvv-muenchen.de and settings to change the data backend<br>- adding support to enable/disable gps")
                            );
 
         settings->setValue("firstLaunch", APP_VER);
@@ -592,6 +592,20 @@ void MainWindow::searchButtonClicked(bool checked)
     }
 }
 
+void MainWindow::closeEvent(QCloseEvent *event)
+{
+    //qDebug() <<"close event";
+    hide();
+    event->accept();
+}
+
+int MainWindow::top_application()
+{
+    //qDebug() <<"top event";
+    show();
+    return 0;
+}
+
 void MainWindow::windowDestroyed(QObject* obj)
 {
     disconnect(obj, SIGNAL(destroyed(QObject*)),
