@@ -32,6 +32,7 @@
 #include <QtCore/QCoreApplication>
 #include <QtCore/QBuffer>
 #include <QtCore/QStringList>
+#include <QCloseEvent>
 #include <qgeopositioninfo.h>
 #include <qgeopositioninfosource.h>
 
@@ -40,7 +41,7 @@
 #include "selectstationdialog.h"
 #include "configdialog.h"
 
-#define APP_VER "0.0.11"
+#define APP_VER "0.0.12"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -54,6 +55,7 @@ public:
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "com.nokia.fahrplan")
 
 public:
     explicit MainWindow(QWidget *parent=0);
@@ -61,6 +63,7 @@ public:
 
 public slots:
     void positionUpdated(QGeoPositionInfo geoPositionInfo);
+    Q_SCRIPTABLE int top_application();
 
 private slots:
     void searchButtonClicked(bool checked = false);
@@ -93,6 +96,7 @@ private:
 
     parserAbstract *backendParser;
 
+    void closeEvent(QCloseEvent *event);
     void showResultWindow();
     void showDetailsWindow();
     bool eventFilter(QObject* pObject, QEvent* pEvent);
